@@ -22,6 +22,9 @@ import java.util.Objects;
 import java.util.function.BiFunction;
 import java.util.function.Predicate;
 import org.apache.lucene.document.IntPoint;
+import org.apache.lucene.index.DocValuesType;
+import org.apache.lucene.index.FieldInfo;
+import org.apache.lucene.index.IndexReader;
 import org.apache.lucene.index.LeafReader;
 import org.apache.lucene.index.LeafReaderContext;
 import org.apache.lucene.index.PointValues;
@@ -54,6 +57,7 @@ public abstract class PointRangeQuery extends Query {
   final int bytesPerDim;
   final byte[] lowerPoint;
   final byte[] upperPoint;
+  final ByteArrayComparator comparator;
 
   /**
    * Expert: create a multidimensional range query for point values.
@@ -89,6 +93,8 @@ public abstract class PointRangeQuery extends Query {
 
     this.lowerPoint = lowerPoint;
     this.upperPoint = upperPoint;
+
+    this.comparator = ArrayUtil.getUnsignedComparator(bytesPerDim);
   }
 
   /**
@@ -125,8 +131,6 @@ public abstract class PointRangeQuery extends Query {
 
     return new ConstantScoreWeight(this, boost) {
 
-      private final ByteArrayComparator comparator = ArrayUtil.getUnsignedComparator(bytesPerDim);
-
       private boolean matches(byte[] packedValue) {
         int offset = 0;
         for (int dim = 0; dim < numDims; dim++, offset += bytesPerDim) {
@@ -142,30 +146,6 @@ public abstract class PointRangeQuery extends Query {
         return true;
       }
 
-      private Relation relate(byte[] minPackedValue, byte[] maxPackedValue) {
-
-        boolean crosses = false;
-        int offset = 0;
-
-        for (int dim = 0; dim < numDims; dim++, offset += bytesPerDim) {
-
-          if (comparator.compare(minPackedValue, offset, upperPoint, offset) > 0
-              || comparator.compare(maxPackedValue, offset, lowerPoint, offset) < 0) {
-            return Relation.CELL_OUTSIDE_QUERY;
-          }
-
-          crosses |=
-              comparator.compare(minPackedValue, offset, lowerPoint, offset) < 0
-                  || comparator.compare(maxPackedValue, offset, upperPoint, offset) > 0;
-        }
-
-        if (crosses) {
-          return Relation.CELL_CROSSES_QUERY;
-        } else {
-          return Relation.CELL_INSIDE_QUERY;
-        }
-      }
-
       private IntersectVisitor getIntersectVisitor(DocIdSetBuilder result) {
         return new IntersectVisitor() {
 
@@ -230,7 +210,7 @@ public abstract class PointRangeQuery extends Query {
 
           @Override
           public void visit(IntsRef ref) {
-            for (int i = ref.offset; i < ref.offset + ref.length; i++) {
+            for (int i = ref.offset, to = ref.offset + ref.length; i < to; i++) {
               result.set(ref.ints[i]);
             }
             cost[0] += ref.length;
@@ -268,33 +248,6 @@ public abstract class PointRangeQuery extends Query {
         };
       }
 
-      private boolean checkValidPointValues(PointValues values) throws IOException {
-        if (values == null) {
-          // No docs in this segment/field indexed any points
-          return false;
-        }
-
-        if (values.getNumIndexDimensions() != numDims) {
-          throw new IllegalArgumentException(
-              "field=\""
-                  + field
-                  + "\" was indexed with numIndexDimensions="
-                  + values.getNumIndexDimensions()
-                  + " but this query has numDims="
-                  + numDims);
-        }
-        if (bytesPerDim != values.getBytesPerDimension()) {
-          throw new IllegalArgumentException(
-              "field=\""
-                  + field
-                  + "\" was indexed with bytesPerDim="
-                  + values.getBytesPerDimension()
-                  + " but this query has bytesPerDim="
-                  + bytesPerDim);
-        }
-        return true;
-      }
-
       @Override
       public ScorerSupplier scorerSupplier(LeafReaderContext context) throws IOException {
         LeafReader reader = context.reader();
@@ -402,7 +355,8 @@ public abstract class PointRangeQuery extends Query {
           // docCount == size : counting according number of points in leaf node, so must be
           // single-valued.
           if (numDims == 1 && values.getDocCount() == values.size()) {
-            return (int) pointCount(values.getPointTree(), this::relate, this::matches);
+            return (int)
+                pointCount(values.getPointTree(), PointRangeQuery.this::relate, this::matches);
           }
         }
         return super.count(context);
@@ -580,4 +534,118 @@ public abstract class PointRangeQuery extends Query {
    * @return human readable value for debugging
    */
   protected abstract String toString(int dimension, byte[] value);
+
+  @Override
+  public Query rewrite(IndexSearcher searcher) throws IOException {
+    IndexReader reader = searcher.getIndexReader();
+
+    for (LeafReaderContext leaf : reader.leaves()) {
+      checkValidPointValues(leaf.reader().getPointValues(field));
+    }
+
+    // fetch the global min/max packed values across all segments
+    byte[] globalMinPacked = PointValues.getMinPackedValue(reader, getField());
+    byte[] globalMaxPacked = PointValues.getMaxPackedValue(reader, getField());
+
+    if (globalMinPacked == null || globalMaxPacked == null) {
+      return new MatchNoDocsQuery();
+    }
+
+    return switch (relate(globalMinPacked, globalMaxPacked)) {
+      case CELL_INSIDE_QUERY -> {
+        if (canRewriteToMatchAllQuery(reader)) {
+          yield new MatchAllDocsQuery();
+        } else if (canRewriteToFieldExistsQuery(reader)) {
+          yield new FieldExistsQuery(field);
+        } else {
+          yield super.rewrite(searcher);
+        }
+      }
+      case CELL_OUTSIDE_QUERY -> new MatchNoDocsQuery();
+      case CELL_CROSSES_QUERY -> super.rewrite(searcher);
+    };
+  }
+
+  private boolean canRewriteToMatchAllQuery(IndexReader reader) throws IOException {
+    for (LeafReaderContext context : reader.leaves()) {
+      LeafReader leaf = context.reader();
+      PointValues values = leaf.getPointValues(field);
+
+      if (values == null || values.getDocCount() != leaf.maxDoc()) {
+        return false;
+      }
+    }
+
+    return true;
+  }
+
+  private boolean canRewriteToFieldExistsQuery(IndexReader reader) {
+    for (LeafReaderContext leaf : reader.leaves()) {
+      FieldInfo info = leaf.reader().getFieldInfos().fieldInfo(field);
+
+      if (info != null
+          && info.getDocValuesType() == DocValuesType.NONE
+          && !info.hasNorms()
+          && info.getVectorDimension() == 0) {
+        // Can't use a FieldExistsQuery on this segment, so return false
+        return false;
+      }
+    }
+
+    return true;
+  }
+
+  private Relation relate(byte[] minPackedValue, byte[] maxPackedValue) {
+    boolean crosses = false;
+    int offset = 0;
+
+    for (int dim = 0; dim < numDims; dim++, offset += bytesPerDim) {
+
+      if (comparator.compare(minPackedValue, offset, upperPoint, offset) > 0
+          || comparator.compare(maxPackedValue, offset, lowerPoint, offset) < 0) {
+        return Relation.CELL_OUTSIDE_QUERY;
+      }
+
+      // Evaluate crosses only when false. Still need to iterate through
+      // all the dimensions to ensure, none of them is completely outside
+      if (crosses == false) {
+        crosses =
+            comparator.compare(minPackedValue, offset, lowerPoint, offset) < 0
+                || comparator.compare(maxPackedValue, offset, upperPoint, offset) > 0;
+      }
+    }
+
+    if (crosses) {
+      return Relation.CELL_CROSSES_QUERY;
+    } else {
+      return Relation.CELL_INSIDE_QUERY;
+    }
+  }
+
+  private boolean checkValidPointValues(PointValues values) throws IOException {
+    if (values == null) {
+      // No docs in this segment/field indexed any points
+      return false;
+    }
+
+    if (values.getNumIndexDimensions() != numDims) {
+      throw new IllegalArgumentException(
+          "field=\""
+              + field
+              + "\" was indexed with numIndexDimensions="
+              + values.getNumIndexDimensions()
+              + " but this query has numDims="
+              + numDims);
+    }
+    if (bytesPerDim != values.getBytesPerDimension()) {
+      throw new IllegalArgumentException(
+          "field=\""
+              + field
+              + "\" was indexed with bytesPerDim="
+              + values.getBytesPerDimension()
+              + " but this query has bytesPerDim="
+              + bytesPerDim);
+    }
+    return true;
+  }
 }
