@@ -88,6 +88,24 @@ public class TestFieldExistsQuery extends LuceneTestCase {
     dir.close();
   }
 
+  public void testDocValuesRewriteWithDocValuesSkipperPresent() throws IOException {
+    Directory dir = newDirectory();
+    RandomIndexWriter iw = new RandomIndexWriter(random(), dir);
+    final int numDocs = atLeast(100);
+    for (int i = 0; i < numDocs; ++i) {
+      Document doc = new Document();
+      doc.add(NumericDocValuesField.indexedField("dim", 2));
+      iw.addDocument(doc);
+    }
+    iw.commit();
+    final IndexReader reader = iw.getReader();
+    iw.close();
+
+    assertEquals(new MatchAllDocsQuery(), new FieldExistsQuery("dim").rewrite(newSearcher(reader)));
+    reader.close();
+    dir.close();
+  }
+
   public void testDocValuesNoRewrite() throws IOException {
     Directory dir = newDirectory();
     RandomIndexWriter iw = new RandomIndexWriter(random(), dir);
@@ -741,6 +759,41 @@ public class TestFieldExistsQuery extends LuceneTestCase {
     return v;
   }
 
+  public void testDeleteDocValues() throws IOException {
+    try (Directory dir = newDirectory();
+        RandomIndexWriter iw = new RandomIndexWriter(random(), dir)) {
+      final int numDocs = atLeast(100);
+
+      boolean allDocsHaveValue = random().nextBoolean();
+      BitSet docWithValue = new FixedBitSet(numDocs);
+      for (int i = 0; i < numDocs; ++i) {
+        Document doc = new Document();
+        if (allDocsHaveValue || random().nextBoolean()) {
+          doc.add(NumericDocValuesField.indexedField("num", i));
+          docWithValue.set(i);
+        }
+        doc.add(new StringField("id", Integer.toString(i), Store.NO));
+        iw.addDocument(doc);
+      }
+
+      if (random().nextBoolean()) {
+        final int numDeleted = random().nextInt(numDocs) + 1;
+        for (int i = 0; i < numDeleted; ++i) {
+          int id = random().nextInt(numDocs);
+          iw.deleteDocuments(new Term("id", Integer.toString(id)));
+          docWithValue.clear(id);
+        }
+      }
+
+      try (IndexReader reader = iw.getReader()) {
+        final IndexSearcher searcher = newSearcher(reader);
+
+        final int count = searcher.count(new FieldExistsQuery("num"));
+        assertEquals(docWithValue.cardinality(), count);
+      }
+    }
+  }
+
   public void testDeleteAllPointDocs() throws Exception {
     try (Directory dir = newDirectory();
         RandomIndexWriter iw = new RandomIndexWriter(random(), dir)) {
