@@ -24,7 +24,6 @@ import java.util.HashSet;
 import java.util.Set;
 import java.util.concurrent.Callable;
 import java.util.concurrent.Executor;
-import java.util.concurrent.ForkJoinPool;
 import org.apache.lucene.codecs.CodecUtil;
 import org.apache.lucene.index.CodecReader;
 import org.apache.lucene.index.DocValues;
@@ -125,7 +124,6 @@ public final class BPIndexReorderer {
   private float maxDocFreq;
   private int minPartitionSize;
   private int maxIters;
-  private ForkJoinPool forkJoinPool;
   private double ramBudgetMB;
   private Set<String> fields;
 
@@ -182,19 +180,6 @@ public final class BPIndexReorderer {
     this.maxIters = maxIters;
   }
 
-  /**
-   * Set the {@link ForkJoinPool} to run graph partitioning concurrently.
-   *
-   * <p>NOTE: A value of {@code null} can be used to run in the current thread, which is the
-   * default.
-   *
-   * @deprecated Pass an executor to {@link #reorder(CodecReader, Directory, Executor)} instead
-   */
-  @Deprecated
-  public void setForkJoinPool(ForkJoinPool forkJoinPool) {
-    this.forkJoinPool = forkJoinPool;
-  }
-
   /**
    * Set the amount of RAM that graph partitioning is allowed to use. More RAM allows running
    * faster. If not enough RAM is provided, a {@link NotEnoughRAMException} will be thrown. This is
@@ -281,7 +266,7 @@ public final class BPIndexReorderer {
       this.parents = parents;
     }
 
-    private void computeDocFreqs(IntsRef docs, ForwardIndex forwardIndex, int[] docFreqs) {
+    private static void computeDocFreqs(IntsRef docs, ForwardIndex forwardIndex, int[] docFreqs) {
       try {
         Arrays.fill(docFreqs, 0);
         for (int i = docs.offset, end = docs.offset + docs.length; i < end; ++i) {
@@ -544,7 +529,7 @@ public final class BPIndexReorderer {
       return true;
     }
 
-    private void swapDocsAndFreqs(
+    private static void swapDocsAndFreqs(
         int[] docs,
         int left,
         int right,
@@ -643,7 +628,7 @@ public final class BPIndexReorderer {
      * Compute a float that is negative when a document is attracted to the left and positive
      * otherwise.
      */
-    private float computeBias(
+    private static float computeBias(
         int docID, ForwardIndex forwardIndex, int[] fromDocFreqs, int[] toDocFreqs)
         throws IOException {
       forwardIndex.seek(docID);
@@ -835,8 +820,8 @@ public final class BPIndexReorderer {
               });
     }
 
-    IndexInput termIDsInput = tempDir.openInput(termIDsFileName, IOContext.READ);
-    IndexInput startOffsets = tempDir.openInput(startOffsetsFileName, IOContext.READ);
+    IndexInput termIDsInput = tempDir.openInput(termIDsFileName, IOContext.DEFAULT);
+    IndexInput startOffsets = tempDir.openInput(startOffsetsFileName, IOContext.DEFAULT);
     return new ForwardIndex(startOffsets, termIDsInput, maxTerm);
   }
 
@@ -847,9 +832,6 @@ public final class BPIndexReorderer {
    */
   public Sorter.DocMap computeDocMap(CodecReader reader, Directory tempDir, Executor executor)
       throws IOException {
-    if (executor == null) {
-      executor = forkJoinPool;
-    }
     if (docRAMRequirements(reader.maxDoc()) >= ramBudgetMB * 1024 * 1024) {
       throw new NotEnoughRAMException(
           "At least "
